@@ -8,9 +8,9 @@ static L19();
 static object LI24();
 static object LI25();
 static object LI1();
-static int VK1defaults[5]={-2,-2,-1,-2,-2};
-static struct { short n,allow_other_keys;int *defaults;
-	 int keys[5];} LI1key={5,0,VK1defaults,{67,68,16,69,70}};
+static object VK1defaults[5]={(void *)-2,(void *)-2,(void *)-1,(void *)-2,(void *)-2};
+static struct { short n,allow_other_keys;object *defaults;
+	 KEYTYPE keys[5];} LI1key={5,0,VK1defaults,{(void *)67,(void *)68,(void *)16,(void *)69,(void *)70}};
 #define VMB1 register object *base=vs_top; object Vcs[10];
 #define VMS1  register object *sup=vs_top+6;vs_top=sup;
 #define VMV1 vs_reserve(6);
