@@ -38,18 +38,17 @@ static object LI2(V2,va_alist)
 	base[1]= Ct;
 	base[2]= VV[4];
 	vs_top=(vs_base=base+1)+2;
-	(void) (*Lnk59)();
+	Lformat();
 	vs_top=sup;
-	base[1]=symbol_function(VV[59]);
-	base[2]= Ct;
-	base[3]= (V3);
+	base[1]= Ct;
+	base[2]= (V3);
 	{object V6;
 	V6= (V4);
-	 vs_top=base+4;
+	 vs_top=base+3;
 	 while(!endp(V6))
 	 {vs_push(car(V6));V6=cdr(V6);}
-	vs_base=base+2;}
-	(void) (*Lnk59)();
+	vs_base=base+1;}
+	Lformat();
 	vs_top=sup;
 	setq(VV[5],number_plus(symbol_value(VV[5]),small_fixnum(1)));
 	{frame_ptr fr;
@@ -95,7 +94,7 @@ TTL:;
 	base[4]= (V12);
 	base[5]= (V13);
 	vs_top=(vs_base=base+1)+5;
-	(void) (*Lnk59)();
+	Lformat();
 	vs_top=sup;
 	setq(VV[5],number_plus(symbol_value(VV[5]),small_fixnum(1)));
 	{frame_ptr fr;
@@ -121,7 +120,7 @@ TTL:;
 	base[4]= (V18);
 	base[5]= (V19);
 	vs_top=(vs_base=base+1)+5;
-	(void) (*Lnk59)();
+	Lformat();
 	vs_top=sup;
 	setq(VV[5],number_plus(symbol_value(VV[5]),small_fixnum(1)));
 	{frame_ptr fr;
@@ -155,18 +154,17 @@ static object LI6(V20,va_alist)
 	base[1]= Ct;
 	base[2]= VV[13];
 	vs_top=(vs_base=base+1)+2;
-	(void) (*Lnk59)();
+	Lformat();
 	vs_top=sup;
-	base[1]=symbol_function(VV[59]);
-	base[2]= Ct;
-	base[3]= (V21);
+	base[1]= Ct;
+	base[2]= (V21);
 	{object V24;
 	V24= (V22);
-	 vs_top=base+4;
+	 vs_top=base+3;
 	 while(!endp(V24))
 	 {vs_push(car(V24));V24=cdr(V24);}
-	vs_base=base+2;}
-	(void) (*Lnk59)();
+	vs_base=base+1;}
+	Lformat();
 	vs_top=sup;
 	princ_char(10,Cnil);
 T32:;
@@ -198,18 +196,17 @@ static object LI7(V26,va_alist)
 	base[1]= Ct;
 	base[2]= VV[15];
 	vs_top=(vs_base=base+1)+2;
-	(void) (*Lnk59)();
+	Lformat();
 	vs_top=sup;
-	base[1]=symbol_function(VV[59]);
-	base[2]= Ct;
-	base[3]= (V27);
+	base[1]= Ct;
+	base[2]= (V27);
 	{object V30;
 	V30= (V28);
-	 vs_top=base+4;
+	 vs_top=base+3;
 	 while(!endp(V30))
 	 {vs_push(car(V30));V30=cdr(V30);}
-	vs_base=base+2;}
-	(void) (*Lnk59)();
+	vs_base=base+1;}
+	Lformat();
 	vs_top=sup;
 T43:;
 	{object V31 = Cnil;
@@ -227,7 +224,7 @@ TTL:;
 	goto T53;}
 	setq(VV[16],Cnil);
 	vs_base=vs_top;
-	(void) (*Lnk60)();
+	Lfresh_line();
 	vs_top=sup;
 	if(!(type_of(symbol_value(VV[17]))==t_cons)){
 	goto T60;}
@@ -237,7 +234,7 @@ TTL:;
 	base[1]= VV[19];
 	base[2]= cdr(symbol_value(VV[17]));
 	vs_top=(vs_base=base+0)+3;
-	(void) (*Lnk59)();
+	Lformat();
 	vs_top=sup;
 	goto T53;
 T60:;
@@ -247,7 +244,7 @@ T60:;
 	base[3]= VV[22];
 	base[4]= symbol_value(VV[17]);
 	vs_top=(vs_base=base+2)+3;
-	(void) (*Lnk59)();
+	Lformat();
 	vs_top=sup;
 	bds_unwind1;
 	bds_unwind1;
@@ -269,7 +266,7 @@ TTL:;
 	base[2]= VV[23];
 	base[3]= (V34);
 	vs_top=(vs_base=base+1)+3;
-	(void) (*Lnk59)();
+	Lformat();
 	vs_top=sup;
 	{object V35 = Cnil;
 	bds_unwind1;
@@ -287,10 +284,10 @@ TTL:;
 	base[1]= Ct;
 	base[2]= VV[24];
 	vs_top=(vs_base=base+1)+2;
-	(void) (*Lnk59)();
+	Lformat();
 	vs_top=sup;
 	setq(VV[5],number_plus(symbol_value(VV[5]),small_fixnum(1)));
-	{object V36 = (VFUN_NARGS=0,(*(LnkLI61))());
+	{object V36 = (VFUN_NARGS=0,(*(LnkLI59))());
 	bds_unwind1;
 	VMR10(V36)}
 }
@@ -321,7 +318,7 @@ static L11()
 	base[5]= V37;}
 	{register object V39;
 	vs_base=vs_top;
-	(void) (*Lnk62)();
+	Lgensym();
 	vs_top=sup;
 	V39= vs_base[0];
 	V40= list(3,(V39),base[3],list(2,VV[26],(V39)));
@@ -359,7 +356,7 @@ static L12()
 	base[5]= V44;}
 	{register object V46;
 	vs_base=vs_top;
-	(void) (*Lnk62)();
+	Lgensym();
 	vs_top=sup;
 	V46= vs_base[0];
 	V47= list(3,(V46),base[3],list(2,VV[26],(V46)));
@@ -397,7 +394,7 @@ static L13()
 	base[5]= V51;}
 	{object V53;
 	vs_base=vs_top;
-	(void) (*Lnk62)();
+	Lgensym();
 	vs_top=sup;
 	V53= vs_base[0];
 	V54= list(2,(V53),base[3]);
@@ -434,7 +431,7 @@ static L14()
 	base[5]= V57;}
 	{object V59;
 	vs_base=vs_top;
-	(void) (*Lnk62)();
+	Lgensym();
 	vs_top=sup;
 	V59= vs_base[0];
 	V60= list(2,(V59),base[3]);
@@ -457,11 +454,10 @@ static L15()
 	vs_top=sup;
 TTL:;
 	{object V64;
-	base[1]=symbol_function(VV[63]);
-	base[2]= list(2,VV[34],list(2,VV[35],(V63)));
-	vs_top=(vs_base=base+2)+1;
-	(void) (*Lnk64)();
-	(void) (*Lnk63)();
+	base[1]= list(2,VV[34],list(2,VV[35],(V63)));
+	vs_top=(vs_base=base+1)+1;
+	(void) (*Lnk60)();
+	Llist();
 	vs_top=sup;
 	V64= vs_base[0];
 	if((car((V64)))==Cnil){
@@ -473,7 +469,7 @@ TTL:;
 	base[3]= VV[36];
 	base[4]= (V63);
 	vs_top=(vs_base=base+2)+3;
-	(void) (*Lnk59)();
+	Lformat();
 	vs_top=sup;
 	base[2]= Cnil;
 	vs_top=(vs_base=base+2)+1;
@@ -482,7 +478,7 @@ TTL:;
 T93:;
 	base[1]= cdr((V64));
 	vs_top=(vs_base=base+1)+1;
-	(void) (*Lnk65)();
+	Lvalues_list();
 	return;}
 	}
 }
@@ -520,12 +516,11 @@ T104:;
 	V67= list(3,Cnil,/* INLINE-ARGS */V71,Cnil);
 T122:;
 	{object V72;
-	base[0]=symbol_function(VV[63]);
 	V73= list(2,VV[35],(V66));
-	base[1]= list(3,VV[39],/* INLINE-ARGS */V73,list(2,VV[35],(V67)));
-	vs_top=(vs_base=base+1)+1;
-	(void) (*Lnk64)();
-	(void) (*Lnk63)();
+	base[0]= list(3,VV[39],/* INLINE-ARGS */V73,list(2,VV[35],(V67)));
+	vs_top=(vs_base=base+0)+1;
+	(void) (*Lnk60)();
+	Llist();
 	vs_top=sup;
 	V72= vs_base[0];
 	if((car((V72)))==Cnil){
@@ -537,7 +532,7 @@ T122:;
 	base[2]= VV[40];
 	base[3]= (V66);
 	vs_top=(vs_base=base+1)+3;
-	(void) (*Lnk59)();
+	Lformat();
 	vs_top=sup;
 	{object V74 = list(3,VV[41],VV[42],list(2,VV[35],(V66)));
 	bds_unwind1;
@@ -575,12 +570,11 @@ T149:;
 	goto T144;}
 T140:;
 	{object V82;
-	base[0]=symbol_function(VV[63]);
 	V83= list(2,VV[35],(V77));
-	base[1]= list(3,VV[43],/* INLINE-ARGS */V83,list(2,VV[35],(V78)));
-	vs_top=(vs_base=base+1)+1;
-	(void) (*Lnk64)();
-	(void) (*Lnk63)();
+	base[0]= list(3,VV[43],/* INLINE-ARGS */V83,list(2,VV[35],(V78)));
+	vs_top=(vs_base=base+0)+1;
+	(void) (*Lnk60)();
+	Llist();
 	vs_top=sup;
 	V82= vs_base[0];
 	if((car((V82)))==Cnil){
@@ -592,7 +586,7 @@ T140:;
 	base[2]= VV[44];
 	base[3]= (V77);
 	vs_top=(vs_base=base+1)+3;
-	(void) (*Lnk59)();
+	Lformat();
 	vs_top=sup;
 	{object V84 = list(3,VV[41],VV[45],list(2,VV[35],(V77)));
 	bds_unwind1;
@@ -631,7 +625,7 @@ T181:;
 T172:;
 	if(symbol_value(VV[46])==Cnil){
 	goto T190;}
-	(void)((*(LnkLI66))((V90)));
+	(void)((*(LnkLI61))((V90)));
 T190:;
 	if(((V92))==Cnil){
 	goto T191;}
@@ -639,13 +633,12 @@ T190:;
 	V92= list(3,Cnil,/* INLINE-ARGS */V96,Cnil);
 T191:;
 	{object V97;
-	base[0]=symbol_function(VV[63]);
 	V98= list(2,VV[35],(V89));
 	V99= list(2,VV[35],make_cons((V90),(V91)));
-	base[1]= list(5,VV[47],VV[48],/* INLINE-ARGS */V98,/* INLINE-ARGS */V99,list(2,VV[35],(V92)));
-	vs_top=(vs_base=base+1)+1;
-	(void) (*Lnk64)();
-	(void) (*Lnk63)();
+	base[0]= list(5,VV[47],VV[48],/* INLINE-ARGS */V98,/* INLINE-ARGS */V99,list(2,VV[35],(V92)));
+	vs_top=(vs_base=base+0)+1;
+	(void) (*Lnk60)();
+	Llist();
 	vs_top=sup;
 	V97= vs_base[0];
 	if((car((V97)))==Cnil){
@@ -657,7 +650,7 @@ T191:;
 	base[2]= VV[49];
 	base[3]= (V90);
 	vs_top=(vs_base=base+1)+3;
-	(void) (*Lnk59)();
+	Lformat();
 	vs_top=sup;
 	{object V100 = list(3,VV[41],VV[50],list(2,VV[35],make_cons((V90),(V91))));
 	bds_unwind1;
@@ -680,20 +673,20 @@ static L19()
 TTL:;
 	bds_bind(VV[51],symbol_value(VV[52]));
 	vs_base=vs_top;
-	(void) (*Lnk67)();
+	(void) (*Lnk62)();
 	vs_top=sup;
 	V103= vs_base[0];
 	bds_bind(VV[52],one_minus(V103));
 	bds_bind(VV[53],symbol_value(VV[54]));
 	base[5]= VV[56];
 	vs_top=(vs_base=base+5)+1;
-	(void) (*Lnk68)();
+	Lfind_package();
 	vs_top=sup;
 	V104= vs_base[0];
 	bds_bind(VV[55],make_cons(V104,symbol_value(VV[55])));
 	base[5]= (V102);
 	vs_top=(vs_base=base+5)+1;
-	(void) (*Lnk69)();
+	(void) (*Lnk63)();
 	bds_unwind1;
 	bds_unwind1;
 	bds_unwind1;
@@ -722,7 +715,7 @@ TTL:;
 	register object V115;
 	base[0]= (V112);
 	vs_top=(vs_base=base+0)+1;
-	(void) (*Lnk70)();
+	Lsymbol_plist();
 	vs_top=sup;
 	V114= vs_base[0];
 	V115= Cnil;
@@ -737,34 +730,22 @@ T221:;
 	goto T224;
 T226:;
 	V114= cddr((V114));
-T224:;{object V116;
-	base[0]= (V114);
-	vs_top=(vs_base=base+0)+1;
-	(void) (*Lnk71)();
-	vs_top=sup;
-	V116= vs_base[0];
-	if(V116==Cnil)goto T234;
+T224:;
+	if(!(((V114))==Cnil)){
+	goto T234;}
 	goto T233;
-T234:;}
+T234:;
 	goto T221;
 T233:;
 	goto T219;
 T219:;
-	{object V117 = (*(LnkLI72))((V112),(V113));
-	VMR21(V117)}}
+	{object V116 = (*(LnkLI64))((V112),(V113));
+	VMR21(V116)}}
 }
-static object  LnkTLI72(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[72],&LnkLI72,2,ap);} /* COMPILER-DEF-HOOK */
-static LnkT71(){ call_or_link(VV[71],&Lnk71);} /* NULL */
-static LnkT70(){ call_or_link(VV[70],&Lnk70);} /* SYMBOL-PLIST */
-static LnkT69(){ call_or_link(VV[69],&Lnk69);} /* ERROR-SET */
-static LnkT68(){ call_or_link(VV[68],&Lnk68);} /* FIND-PACKAGE */
-static LnkT67(){ call_or_link(VV[67],&Lnk67);} /* IHS-TOP */
-static object  LnkTLI66(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[66],&LnkLI66,1,ap);} /* ADD-MACRO-CALLEE */
-static LnkT65(){ call_or_link(VV[65],&Lnk65);} /* VALUES-LIST */
-static LnkT63(){ call_or_link(VV[63],&Lnk63);} /* LIST */
-static LnkT64(){ call_or_link(VV[64],&Lnk64);} /* CMP-TOPLEVEL-EVAL */
-static LnkT62(){ call_or_link(VV[62],&Lnk62);} /* GENSYM */
-static object  LnkTLI61(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[61],&LnkLI61,ap);} /* BREAK */
-static LnkT60(){ call_or_link(VV[60],&Lnk60);} /* FRESH-LINE */
-static LnkT59(){ call_or_link(VV[59],&Lnk59);} /* FORMAT */
+static object  LnkTLI64(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[64],&LnkLI64,2,ap);} /* COMPILER-DEF-HOOK */
+static LnkT63(){ call_or_link(VV[63],&Lnk63);} /* ERROR-SET */
+static LnkT62(){ call_or_link(VV[62],&Lnk62);} /* IHS-TOP */
+static object  LnkTLI61(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[61],&LnkLI61,1,ap);} /* ADD-MACRO-CALLEE */
+static LnkT60(){ call_or_link(VV[60],&Lnk60);} /* CMP-TOPLEVEL-EVAL */
+static object  LnkTLI59(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[59],&LnkLI59,ap);} /* BREAK */
 static object  LnkTLI58(){return call_proc0(VV[58],&LnkLI58);} /* PRINT-CURRENT-FORM */
