@@ -1,9 +1,7 @@
-;; Run gcl under Emacs
-;; Author: W. Schelter, University of Texas
-;;     wfs@rascal.ics.utexas.edu
-
+;; Run gcl,maxima,gdb etc under Emacs all possibly all in one buffer.
+;;  
 ;; This file is part of GNU Emacs.
-;; Copyright (C) 1988 Free Software Foundation, Inc.
+;; Copyright (C) 1998 William F. Schelter
 
 ;; GNU Emacs is distributed in the hope that it will be useful, but
 ;; WITHOUT ANY WARRANTY.  No author or distributor accepts responsibility
@@ -37,7 +35,7 @@
 
 ;; You may easily create additional commands and bindings to interact
 ;; with the display.  For example to put the dbl command next on \M-n
-;; (def-dbl next "\M-n")
+;; (def-dbl :next "\M-n")
 
 ;; This causes the emacs command dbl-next to be defined, and runs
 ;; dbl-display-frame after the command.
@@ -55,10 +53,29 @@
 
 
 (require 'sshell)
+(require 'smart-complete)
 (require 'gcl)
+(autoload 'maxima-mode "maxima-mode" "Major mode for editing maxima code and interacting with debugger" t)
+(autoload 'gcl-mode "gcl" "Major mode for editing maxima code and interacting with debugger" t)
+(setq auto-mode-alist (cons '("\\.ma?[cx]\\'" . maxima-mode) auto-mode-alist))
+(setq auto-mode-alist (cons '("\\.li?sp\\'" . gcl-mode) auto-mode-alist))
 
-(defvar dbl-prompt-pattern "\\(^(.*gdb[+]*) *\\)\\|\\(^[^#$%>]*[#$%>]+ *\\)"
-  "A regexp to recognize the prompt for dbl or dbl+.") 
+(defvar dbl-prompt-pattern
+   "\\(^\\|\n\\)[^ >]*[>$)%#:][>]*[ ]*"
+  ; "(^|\n)\\[^ >]*[>$)%#:][>]*[ ]*+"
+  "A regexp to recognize the prompt for dbl or dbl+.")
+;
+
+(defvar downcase-filenames-for-dbl
+  (string-match "nt[45]" system-configuration)
+  "Force the case to be lower when sending a break command" 
+  )
+
+(defvar dbl-subshell-switches
+  (list "bash"  (if (string-match "nt[45]" system-configuration) '("--noediting" "-i")  '("-i"))
+	)
+  "Alternating list of regexp for the shell name, and list of switches to pass"
+  )
 
 (defvar dbl-filter-accumulator nil)
 (defvar dbl-mode-map nil
@@ -67,7 +84,7 @@
 (if dbl-mode-map
    nil
   (setq dbl-mode-map (copy-keymap sshell-mode-map))
-  (define-key dbl-mode-map "\C-cl" 'dbl-find-line)
+  (define-key dbl-mode-map "\C-cl" 'dbl-find-and-display-line)
   )
 
 (define-key ctl-x-map " " 'dbl-break)
@@ -77,30 +94,41 @@
 ;;user defined ones.   
 
 (defmacro def-dbl (name key &optional doc)
-  (let* ((fun (intern (format "dbl-%s" name)))
-	 (cstr (list 'if '(not (= 1 arg))
-		     (list 'format "%s %s" name 'arg)
-		     name)))
+  (let* ((fun (intern (format "dbl-%s" (read name))))
+	 )
     (list 'progn
  	  (list 'defun fun '(arg)
 		(or doc "")
 		'(interactive "p")
-		(list 'dbl-call cstr))
+		(list 'dbl-call name 'arg))
 	  (list 'define-key 'dbl-mode-map key  (list 'quote fun)))))
 
-(def-dbl ":step"   "\M-s" "Step one source line with display")
-(def-dbl ":step"  "\M-i" "Step one instruction with display")
-(def-dbl ":next"   "\M-n" "Step one source line (skip functions)")
+(def-dbl ":step %p"   "\M-s" "Step one source line with display")
+(def-dbl ":step %p"   "\C-c\C-s" "Step one source line with display")
+(def-dbl ":stepi %p"  "\C-c\t" "Step one instruction with display")
+(def-dbl ":next %p"   "\M-n" "Step one source line (skip functions)")
+(def-dbl ":next %p"   "\C-c\C-n" "Step one source line (skip functions)")
 (def-dbl ":r"   "\M-c" "Continue with display")
 
-(def-dbl "finish" "\C-c\C-f" "Finish executing current function")
-(def-dbl ":up"     "\M-u"   "Go up N stack frames (numeric arg) with display")
-(def-dbl ":down"   "\M-d"   "Go down N stack frames (numeric arg) with display")
+(def-dbl ":finish" "\C-c\C-f" "Finish executing current function")
+(def-dbl ":up %p"     "\C-cu"   "Go up N stack frames (numeric arg) with display")
+(def-dbl ":down %p"   "\C-cd"   "Go down N stack frames (numeric arg) with display")
 
 
 (defun dbl-mode ()
-  "Major mode for interacting with an inferior Dbl process.
-The following commands are available:
+  "Major mode for interacting with an inferior Lisp or Maxima process.
+It is like an ordinary shell, except that it understands certain special
+redisplay commands sent by the process, such as redisplay a source file
+in the other window, positioning a little arrow `==>', at a certain
+line, typically the line where you are stopped in the debugger.
+
+It uses completion based on the form of your current prompt, allowing
+you to keep separate the commands you type at the debugger level and
+the lisp or maxima level.
+
+The source files should be viewed using gcl mode for lisp, and maxima-mode
+for maxima.  
+
 
 \\{dbl-mode-map}
 
@@ -110,7 +138,7 @@ the last line referred to in the dbl buffer.
 \\[dbl-:step] and \\[dbl-:next] in the dbl window,
 call dbl to step and next and then update the other window
 with the current file and position.
-
+o
 If you are in a source file, you may select a point to break
 at, by doing \\[dbl-break].
 
@@ -122,7 +150,47 @@ Additionally we have:
 \\[dbl-:step] advance one line in program
 \\[dbl-:next] advance one line in program (skip over calls).
 \\[send-dbl-command] used for special printing of an arg at the current point.
-C-x SPACE sets break point at current line."
+C-x SPACE sets break point at current line.
+
+You may also enter keyword break commands.
+
+:a  show-break-variables
+:b  simple-backtrace
+:bds  break-bds
+:bl  break-locals
+:blocks  break-blocks
+:break  insert a break point here
+:bs  break-backward-search-stack
+:bt  dbl-backtrace
+:c  break-current
+:delete  (lambda (&rest l) (iterate-over-bkpts l delete) (values))
+:disable  [n1 .. nk] disable break points. [see :info :bkpt]
+:down [n]  move n frames down
+:enable  [n1 n2 ..nk] enable break points
+:env  describe-environment
+:fr  [n] show this frame
+:fs  break-forward-search-stack
+:functions  break-functions
+:go  break-go
+:h  break-help
+:help  break-help
+:ihs  ihs-backtrace
+:info :bkpt show break points.
+:loc  loc
+:m  break-message
+:n  break-next
+:next  step-next
+:p  break-previous
+:q  break-quit
+:r  resume
+:resume  (lambda () resume)
+:s  search-stack
+:step  step-into
+:t  throw-macsyma-top
+:up  move up one frame
+:vs  break-vs
+
+"
   (interactive)
   (kill-all-local-variables)
   (setq major-mode 'dbl-mode)
@@ -147,12 +215,12 @@ C-x SPACE sets break point at current line."
 
 (defvar current-dbl-buffer nil)
 
-(defvar dbl-command-name (if (file-exists-p "/bin/csh") "/bin/csh"
+(defvar dbl-command-name (if (file-exists-p "/bin/bash") "/bin/bash"
 			   "/bin/sh")
   "Pathname for executing dbl.")
 
 
-(defun dbl (arg)
+(defun dbl (p)
  
  "Makes a dbl buffer, suitable for running an inferior
   gcl.  You are prompted for a name for the buffer.  After the shell
@@ -160,18 +228,47 @@ C-x SPACE sets break point at current line."
   has special keybindings for stepping and viewing sources.  Enter the
   debug loop with (si::dbl) or :dbl in a debug loop.  "
 
-  (interactive "sName: ")
-  (let ((file arg) tem
-	(dir default-directory))
-    (switch-to-buffer (concat "*dbl-" file "*"))
-    (setq default-directory
-	  (if (and (setq tem (file-name-directory file))
-		   (file-directory-p  tem))
-	      tem    dir))
+  (interactive "p")
+  
+  (let ( tem
+	(dir default-directory)
+	;; important for winnt version of emacs
+	(binary-process-input t)
+	(binary-process-output nil)
+	switches
+	(name (concat "dbl" (if (equal p 1) "" p) ""))
+	)
+    
+    (switch-to-buffer (concat "*" name "*"))
     (or (bolp) (newline))
     (insert "Current directory is " default-directory "\n")
-    (make-sshell (concat "dbl-" file) dbl-command-name nil )
+    (let ((tem dbl-subshell-switches) switches)
+      (while tem
+	(cond ((string-match (car tem) dbl-command-name)
+	       (setq switches (nth 1 tem)) (setq tem nil))
+	      (t (setq tem (nthcdr 2 tem)))))
+      (apply 'make-sshell name dbl-command-name nil switches))
     (dbl-mode)
+    (make-local-variable 'sshell-prompt-pattern)
+    (setq sshell-prompt-pattern dbl-prompt-pattern)
+    (goto-char (point-min))
+    (insert "
+Welcome to DBL a Debugger for Lisp, Maxima, Gdb and others.
+
+You start your program as usually would in a shell.  For Lisp and
+Maxima the debugger commands begin with a ':', and there is
+completion.  Typing ':' should list all the commands.  In GCL these
+are typed when in the debugger, and in Maxima they may be typed at any
+time.  To see the wonderful benefits of this mode, type C-h m.
+
+Note you may also use this mode to run gdb.  In fact I often debug
+MAXIMA over GCL using gdb, thus having three debuggers at once.
+To run gdb and enable the automatic line display, you must supply
+the `--fullname' keyword as in:
+
+ gdb your-file  --fullname
+")
+    (goto-char (point-max))
     (set-process-filter (get-buffer-process (current-buffer)) 'dbl-filter)
     (set-process-sentinel (get-buffer-process (current-buffer)) 'dbl-sentinel)
     (dbl-set-buffer)))
@@ -186,12 +283,23 @@ C-x SPACE sets break point at current line."
 ;; each filename-and-line-number;
 ;; that DBL prints to identify the selected frame.
 ;; It records the filename and line number, and maybe displays that file.
+(defun dbl-filter (proc string)
+  (let ((inhibit-quit t))
+    (set-buffer (process-buffer proc))
+    (goto-char (point-max))
+    (insert string)
+    (goto-char (point-max))
+    ))
+
+
 (defun dbl-filter (proc string)
   (let ((inhibit-quit t))
     (if dbl-filter-accumulator
 	(dbl-filter-accumulate-marker proc
 				      (concat dbl-filter-accumulator string))
-	(dbl-filter-scan-input proc string))))
+	(dbl-filter-scan-input proc string))
+    ))
+
 
 (defun dbl-filter-accumulate-marker (proc string)
   (setq dbl-filter-accumulator nil)
@@ -199,16 +307,25 @@ C-x SPACE sets break point at current line."
       (if (= (aref string 1) ?\032)
 	  (let ((end (string-match "\n" string)))
 	    (if end
-		(progn
-		  (let* ((first-colon (string-match ":" string 2))
-			 (second-colon
-			  (string-match ":" string (1+ first-colon))))
-		    (setq dbl-last-frame
-			  (cons (substring string 2 first-colon)
-				(string-to-int
-				 (substring string (1+ first-colon)
-					    second-colon)))))
-		  (setq dbl-last-frame-displayed-p nil)
+              (progn
+		(setq me string)
+		(cond ((string-match
+			"\032\032\\([A-Za-z]?:?[^:]*\\):\\([0-9]*\\):[^\n]+\n"
+			string)
+		       (setq dbl-last-frame
+			      (cons
+			      (match-string 1 string)
+			      (string-to-int  (match-string 2 string))))
+		       
+		       (cond ((equal (cdr dbl-last-frame)  0)
+			      ;(message "got 0")
+			      ;(sit-for 1)
+			      (setq overlay-arrow-position nil)
+			      (setq 	dbl-last-frame nil)
+			     )
+			     (t   (setq dbl-last-frame-displayed-p nil))
+		       )))
+
 		  (dbl-filter-scan-input proc
 					 (substring string (1+ end))))
 	      (setq dbl-filter-accumulator string)))
@@ -221,17 +338,28 @@ C-x SPACE sets break point at current line."
       (setq dbl-filter-accumulator nil)
       (let ((start (string-match "\032" string)))
 	(if start
-	    (progn (dbl-filter-insert proc (substring string 0 start))
-		   (dbl-filter-accumulate-marker proc
-						 (substring string start)))
+	    (progn
+	      ;; to do fix this so that if dbl-last-frame
+	      ;; changed, then set the current  text property..
+	      ;;
+		(dbl-filter-insert proc (substring string 0 start))
+		
+		(dbl-filter-accumulate-marker proc
+						 (substring string start))
+		)
 	    (dbl-filter-insert proc string)))))
 
 (defun dbl-filter-insert (proc string)
-  (let ((moving (= (point) (process-mark proc)))
-	(output-after-point (< (point) (process-mark proc)))
+  (let (moving
+	output-after-point 
 	(old-buffer (current-buffer))
 	start)
     (set-buffer (process-buffer proc))
+    ;; test to see if we will move the point.   We want that the
+    ;; window-point of the buffer, should be equal to process-mark. 
+    (setq moving (>= (window-point (get-buffer-window (process-buffer proc)))
+		     (- (process-mark proc) 0)))
+    (setq output-after-point (< (point) (process-mark proc)))
     (unwind-protect
 	(save-excursion
 	  ;; Insert the text, moving the process-marker.
@@ -239,6 +367,7 @@ C-x SPACE sets break point at current line."
 	  (setq start (point))
 	  (insert string)
 	  (set-marker (process-mark proc) (point))
+	 ; (setq bill (cons (list 'hi (process-mark proc) (marker-position (process-mark proc)) (point)) bill))
 	  (dbl-maybe-delete-prompt)
 	  ;; Check for a filename-and-line number.
 	  (dbl-display-frame
@@ -249,12 +378,14 @@ C-x SPACE sets break point at current line."
 	       (not (get-buffer-window (current-buffer))))
 	   ;; Display a file only when a new filename-and-line-number appears.
 	   t)
-	  (goto-char (point-max))
-
 	  )
+      (if moving
+	  (set-window-point
+	   (get-buffer-window (process-buffer proc))
+	   (process-mark proc)))
       (set-buffer old-buffer))
-    (if moving (goto-char (process-mark proc)))))
-(setq me nil)
+    ))
+
 (defun dbl-sentinel (proc msg)
   (cond ((null (buffer-name (process-buffer proc)))
 	 ;; buffer killed
@@ -342,24 +473,34 @@ Obeying it means displaying in another window the specified file and line."
 				  (format "%s = %s, add path :" dirs paths))))))
 	     (search-path file dirs)))))
 
+
 (defun dbl-find-line ()
+  "If the current buffer has a process, then look first for a file-line
+property, and if none, then search for a regexp.
+If a non process buffer, just return current file and line number.
+"
   (interactive)
   (save-excursion
     (end-of-line)
-    (cond ((re-search-backward "[a-zA-Z] line [0-9]+)" 300 nil)
-	   (let (at)  
-	     (setq at (point))
-	     (forward-char 1)
-	     (forward-sexp 1)
-	     (setq line (read (current-buffer)))
-	     (search-backward "(")
-	     (setq file  (buffer-substring (+ 1 (point)) (+ 1 at)))
+    (cond ((get-buffer-process (current-buffer))
+	   (cond
+	    ((save-excursion
+	       (beginning-of-line)
+		(get-text-property (point) 'file-line)))
+	    ((progn (end-of-line) (re-search-backward " \\([^: ]+\\):\\([0-9]+\\)" 300 nil))
+	     (setq file (buffer-substring (match-beginning 1) (match-end 1)))
+	     (setq line (buffer-substring (match-beginning 2) (match-end 2)))
+	     (setq line (read line))
 	     (and (integerp line)
 		  (setq file (search-path file 'dbl-dirs))
-		  (dbl-display-line
-		   file line)))))))
-		   
-    
+		  (list file line)))))
+	  (t (list (buffer-file-name) (+ 1 (count-lines (point))))))))
+
+(defun dbl-find-and-display-line ()
+  (interactive)
+  (let ((res (dbl-find-line)))
+    (and res (apply 'dbl-display-line res))))
+
 (defun dbl-display-line (true-file line)
   (let* ((buffer (dbl-find-file true-file))
 	 (window (display-buffer buffer t))
@@ -379,14 +520,68 @@ Obeying it means displaying in another window the specified file and line."
 	     (goto-char pos))))
     (set-window-point window overlay-arrow-position)))
 
-(defun dbl-call (command)
+(defvar dbl-gdb-command-alist '((":step %p" . "step %p")
+				(":next %p" . "next %p")
+				(":stepi" . "stepi %p")
+				(":r" . "r")
+				(":finish" . "finish")
+				(":up %p" . "up %p")
+				( ":down %p" . "down %p")))
+
+(defun dbl-call (command numeric)
   "Invoke dbl COMMAND displaying source in other window."
   (interactive)
+  (save-excursion
+    (goto-char (point-max))
+    (beginning-of-line)
+    (let (com)
+      (cond ((or (looking-at "(gdb")
+		 (member major-mode '(c-mode c++-mode)))
+	     (if (setq com (assoc  command dbl-gdb-command-alist))
+		 (setq command (cdr com))))))
+
+    
+	    ;; to do put in hook here to recognize whether at
+	    ;; maxima or lisp level.
+
+  (setq command (dbl-subtitute-% command numeric))
   (goto-char (point-max))
   (setq dbl-delete-prompt-marker (point-marker))
   (dbl-set-buffer)
   (send-string (get-buffer-process current-dbl-buffer)
-	       (concat command "\n")))
+	       (concat command "\n"))))
+
+(defun dbl-subtitute-% (command n)
+  (let* (result
+	(in-dbl (get-buffer-process (current-buffer)))
+	file-line 
+	)
+    (cond ((string-match "%[fl]" command)
+	   (cond (in-dbl (setq file-line (dbl-find-line)))
+		 (t (setq file-line
+			  (list (buffer-file-name)
+				(+ 1 (count-lines
+							 (point)))))))))
+    (while (and command (string-match "\\([^%]*\\)%\\([adeflp]\\)" command))
+      (let ((letter (string-to-char (substring command (match-beginning 2))))
+	    subst)
+	(cond ((eq letter ?p)
+	       (setq subst (if n (int-to-string n) "")))
+	      ((eq letter ?f)
+	       (setq subst (or (car file-line) "unknown-file")))
+	      ((eq letter ?l)
+	       (setq subst (if (cadr file-line)
+			       (int-to-string (cadr file-line))
+			       "unknown-line")))
+	      ((eq letter ?a)
+	       (setq subst (dbl-read-address))))
+	(setq result (concat result
+			     (substring command (match-beginning 1) (match-end 1))
+			     subst)))
+      (setq command (substring command (match-end 2))))
+    (concat result command)))
+
+
 
 (defun dbl-maybe-delete-prompt ()
   (if (and dbl-delete-prompt-marker
@@ -414,10 +609,6 @@ Obeying it means displaying in another window the specified file and line."
 	     (forward-sexp -1)
 	     (setq name (buffer-substring (point) at))
 	     (beginning-of-line)
-;	     (setq at
-;		   (progn (re-search-forward "^[^;\"\n]+([a-zA-Z ]" (mark) t)
-;			  (forward-char -2)
-;			  (point)))
 	     (setq name (format "(si::break-function '%s %s t)"  name (count-lines 1 where)))
 	     (other-window 1)
 	     (if (get-buffer-process (current-buffer))
@@ -433,6 +624,8 @@ Obeying it means displaying in another window the specified file and line."
 	       (line (save-restriction
 		       (widen)
 		       (1+ (count-lines 1 (point))))))
+	   (and    downcase-filenames-for-dbl
+		   (setq file-name (downcase file-name)))
 	   (send-string (get-buffer-process current-dbl-buffer)
 			(concat "break " file-name ":" line "\n"))))))
 	
@@ -482,3 +675,5 @@ It is for customization by you.")
     (switch-to-buffer current-dbl-buffer)
     (goto-char (dot-max))
     (insert-string comm)))
+
+(provide 'dbl)
