@@ -76,7 +76,7 @@ extern char *inet_ntoa ( struct in_addr in );
 #include "guis.h"
 
 
-FILE *pstreamDebug = stderr;
+FILE *pstreamDebug;
 int fDebugSockets;
 
 
@@ -113,6 +113,7 @@ main(argc, argv)
      char *argv[];
 {
   {int i = argc;
+  pstreamDebug  = stderr; 
    while (--i > 3)
      { if (strcmp(argv[i],"-delay")==0)
 	 { delay = atoi(argv[i+1]);}
@@ -130,10 +131,10 @@ main(argc, argv)
       parent = atoi(argv[3]);
       dfprintf(stderr,"guis, parent is : %d\n", parent);
 
-#ifndef linux
-      p = fork();
-#else
+#ifdef MUST_USE_VFORK
       p = vfork();
+#else
+      p = fork();
 #endif
       dfprintf(stderr, "guis, vfork returned : %d\n", p);
 
@@ -222,7 +223,7 @@ sock_connect_to_name(host_id,  name, async)
   fd = socket( PF_INET, SOCK_STREAM, 0 );
 
   addr.sin_family = PF_INET;
-  addr.sin_port = name;
+  addr.sin_port = htons((unsigned short)(name & 0xffff));
   addr.sin_addr.s_addr = inet_addr( host_id );
   memset( addr.sin_zero, 0, 8 );
     
