@@ -29,8 +29,15 @@ filecpy(save, original, stsize - sizeof(stsize))
 
 #define NUMBER_OPEN_FILES getdtablesize() 
 
+
+extern char etext;
+
+
+
+
 #define SET_REAL_MAXPAGE do { struct rlimit data_rlimit; \
-			       real_maxpage = MAXPAGE ;\
+				extern char etext; \
+			     real_maxpage = MAXPAGE ; \
      	getrlimit(RLIMIT_DATA, &data_rlimit); \
 	real_maxpage = ((unsigned int)&etext + data_rlimit.rlim_cur)/PAGESIZE; \
 	if (real_maxpage > MAXPAGE) \
