@@ -449,22 +449,64 @@ enum smmode {			/*  stream mode  */
 	smm_echo,		/*  echo  */
 	smm_string_input,	/*  string input  */
 	smm_string_output,	/*  string output  */
-	smm_user_defined        /*  for user defined */ 
+	smm_user_defined,        /*  for user defined */
+	smm_socket		/*  Socket stream  */
 };
 
+/* for any stream that takes writec_char, directly (not two_way or echo)
+   ie. 	 smm_output,smm_io, smm_string_output, smm_socket
+ */
+#define STREAM_FILE_COLUMN(str) ((str)->sm.sm_int1)
+
+/* for smm_echo */
+#define ECHO_STREAM_N_UNREAD(strm) ((strm)->sm.sm_int0)
+
+/* file fd for socket */
+#define SOCKET_STREAM_FD(strm) ((strm)->sm.sm_fd)
+#define SOCKET_STREAM_BUFFER(strm) ((strm)->sm.sm_object1)
+
+/*  for     smm_string_input  */
+#define STRING_INPUT_STREAM_NEXT(strm) ((strm)->sm.sm_int0)
+#define STRING_INPUT_STREAM_END(strm) ((strm)->sm.sm_int1)
+
+/* for smm_two_way and smm_echo */
+#define STREAM_OUTPUT_STREAM(strm) ((strm)->sm.sm_object1)
+#define STREAM_INPUT_STREAM(strm) ((strm)->sm.sm_object0)
+
+/* for smm_string_{input,output} */
+#define STRING_STREAM_STRING(strm) ((strm)->sm.sm_object0)
+
 struct stream {
 		FIRSTWORD;
 	FILE	*sm_fp;		/*  file pointer  */
 	object	sm_object0;	/*  some object  */
 	object	sm_object1;	/*  some object */
 	int	sm_int0;	/*  some int  */
-	int	sm_int1;	/*  some int  */
+	int	sm_int1;	/*  column for input or output, stream */
 	char  	*sm_buffer;     /*  ptr to BUFSIZE block of storage */
-	short	sm_mode;	/*  stream mode  */
-				/*  of enum smmode  */
+	char	sm_mode;	/*  stream mode  */
+        unsigned char    sm_flags;         /* flags from gcl_sm_flags */
+        short sm_fd;         /* stream fd */
+     
 };
+/* flags */
+#define GET_STREAM_FLAG(strm,name) ((strm)->sm.sm_flags & (1<<(name)))
+#define SET_STREAM_FLAG(strm,name,val) (val ? \
+                     	((strm)->sm.sm_flags |= (1<<(name))) : \
+			((strm)->sm.sm_flags &= ~(1<<(name)))) 
 
-
+#define GCL_MODE_BLOCKING 1
+#define GCL_MODE_NON_BLOCKING 0
+#define GCL_TCP_ASYNC 1
+     
+enum gcl_sm_flags {
+  gcl_sm_blocking=1,
+  gcl_sm_tcp_async,
+  gcl_sm_input,
+  gcl_sm_output
+  
+};
+  
 #ifdef BSD
 #ifdef SUN3
 #define	BASEFF		(unsigned char *)0xffffffff
@@ -786,7 +828,7 @@ int FIXtemp;
 /*  For IEEEFLOAT, the double may have exponent in the second word
 (little endian) or first word.*/
 
-#if defined(I386) || defined(LITTLE_ENDIAN)
+#if defined(I386) || defined(LITTLE_END)
 #define HIND 1  /* (int) of double where the exponent and most signif is */
 #define LIND 0  /* low part of a double */
 #else /* big endian */
@@ -824,12 +866,15 @@ EXTER object MVloc[10];
 
 /* Set new to be an (object *) whose [i]'th elmt is the
    ith elmnt in a va_list
-   MUST_COPY_VA_LIST should be true, if
-   ((vl[0] != va_arg(ap,object)) ||
-    (vl[1] != va_arg(ap,object)) || .. vl[n-1] != va_arg(ap,object))
-   Normal machines have va_list an ordinary array and a copy is unnecessary.
+   if 
+   ((vl[0] == va_arg(ap,object)) ||
+    (vl[1] == va_arg(ap,object)) || .. vl[n-1] == va_arg(ap,object))
+   you may set
+   #define DONT_COPY_VA_LIST
+   In recent versions of gcc, i think the builtin_alist stuff does not
+   allow setting this.
  */
-#ifndef MUST_COPY_VA_LIST
+#ifdef DONT_COPY_VA_LIST
 #define COERCE_VA_LIST(new,vl,n) new = (object *) (vl)
 #else
 #define COERCE_VA_LIST(new,vl,n) \
