@@ -29,6 +29,7 @@ Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 
 DEFVAR("*AFTER-GBC-HOOK*",sSAafter_gbc_hookA,SI,sLnil,"");
 DEFVAR("*IGNORE-MAXIMUM-PAGES*",sSAignore_maximum_pagesA,SI,sLt,"");
+#define IGNORE_MAX_PAGES (sSAignore_maximum_pagesA ==0 || sSAignore_maximum_pagesA->s.s_dbind !=sLnil) 
 
 void call_after_gbc_hook();
 
@@ -66,8 +67,10 @@ extern char *sbrk();
 #ifdef BSD
 #include <sys/time.h>
 #include <sys/resource.h>
+#ifdef RLIMIT_STACK
 struct rlimit data_rlimit;
-extern char etext;
+#endif
+/* extern char etext; */
 #endif
 
 int reserve_pages_for_signal_handler =30;
@@ -225,8 +228,10 @@ ONCE_MORE:
 		if (tm->tm_npage >= tm->tm_maxpage)
 			goto CALL_GBC;
 		if (available_pages < 1) {
+		  if (sSAignore_maximum_pagesA) {
 			sSAignore_maximum_pagesA->s.s_dbind = Cnil;
 			goto CALL_GBC;
+		      }
 		}
 		p = alloc_page(1);
 		add_page_to_freelist(p,tm);
@@ -251,7 +256,7 @@ CALL_GBC:
 	goto ONCE_MORE;
 
 EXHAUSTED:
-	if (symbol_value(sSAignore_maximum_pagesA) != Cnil) {
+	if (IGNORE_MAX_PAGES) {
 		if (tm->tm_maxpage/2 <= 0)
 			tm->tm_maxpage += 1;
 		else
@@ -304,8 +309,10 @@ ONCE_MORE:
 		if (tm->tm_npage >= tm->tm_maxpage)
 			goto CALL_GBC;
 		if (available_pages < 1) {
+		   if(sSAignore_maximum_pagesA) {
 			sSAignore_maximum_pagesA->s.s_dbind = Cnil;
 			goto CALL_GBC;
+		      }
 		}
 		p = alloc_page(1);
 		add_page_to_freelist(p,tm);
@@ -331,7 +338,7 @@ CALL_GBC:
 	goto ONCE_MORE;
 
 EXHAUSTED:
-	if (symbol_value(sSAignore_maximum_pagesA) != Cnil) {
+	if (IGNORE_MAX_PAGES) {
 	  tm->tm_maxpage =
 	    grow_linear(tm->tm_maxpage,tm->tm_growth_percent,
 			tm->tm_min_grow,tm->tm_max_grow);
@@ -432,6 +439,7 @@ ONCE_MORE:
 			return(p);
 		}
 	m = (n + PAGESIZE - 1)/PAGESIZE;
+       if(sSAignore_maximum_pagesA) {
 	if (ncbpage + m > maxcbpage || available_pages < m) {
 		if (available_pages < m)
 			sSAignore_maximum_pagesA->s.s_dbind = Cnil;
@@ -441,7 +449,7 @@ ONCE_MORE:
 			call_after_gbc_hook(t_contiguous);
 			goto ONCE_MORE;
 		}
-		if (symbol_value(sSAignore_maximum_pagesA) != Cnil)
+		if (IGNORE_MAX_PAGES)
 		  {struct typemanager *tm = &tm_table[(int)t_contiguous];
 		   maxcbpage=grow_linear(maxcbpage,tm->tm_growth_percent,
 			      tm->tm_min_grow, tm->tm_max_grow);
@@ -459,7 +467,7 @@ Use ALLOCATE-CONTIGUOUS-PAGES to expand the space.",
 		call_after_gbc_hook(t_contiguous);
 		goto ONCE_MORE;
 	}
-
+      }
 	p = alloc_page(m);
 
 	for (i = 0;  i < m;  i++)
@@ -524,7 +532,7 @@ ONCE_MORE:
 				goto ONCE_MORE;
 					      }}
 		}
-		if (symbol_value(sSAignore_maximum_pagesA) != Cnil)
+		if (IGNORE_MAX_PAGES)
 		  {struct typemanager *tm = &tm_table[(int)t_relocatable];
 		   nrbpage=grow_linear(i=nrbpage,tm->tm_growth_percent,
 			      tm->tm_min_grow, tm->tm_max_grow);
@@ -727,6 +735,10 @@ init_alloc()
 	
 }
 
+DEFUN("STATICP",object,fSstaticp,SI,1,1,NONE,OO,OO,OO,OO,"Tell if the string or vector is static") (x)
+object x;
+{ RETURN1((inheap(x->ust.ust_self) ? sLt : sLnil));
+}
 
 cant_get_a_type()
 {
@@ -1013,14 +1025,61 @@ object malloc_list;
 #include "malloc.c"
 #else
 
+/* a very young malloc may use this simple baby malloc, for the init
+ code before we even get to main.c.  If this is not defined, then
+ malloc will try to run the init code which will work on many machines
+ but some such as WindowsNT under cygwin need this.
+ 
+ */
+#ifdef BABY_MALLOC_SIZE
+
+/* by giving an initialization, make it not be in bss, since
+   bss may not get loaded until main is reached.  We may
+   not even know our own name at this stage. */
+static char baby_malloc_data[BABY_MALLOC_SIZE]={1,0};
+static char *last_baby= baby_malloc_data;
+
+static char *baby_malloc(n)
+     int n;
+{
+  char *res= last_baby;
+  int m;
+  n = ROUND_UP_PTR(n);
+   m = n+ sizeof(int);
+  if ((res +m-baby_malloc_data) > sizeof(baby_malloc_data))
+    {
+     printf("failed in baby malloc");
+     exit(1);
+    }
+  last_baby += m;
+  *((int *)res)=n;
+  return res+sizeof(int);
+}
+#endif
+
+
+
 char *
 malloc(size)
 int size;
 {
 	object x;
 
-	if (GBC_enable==0 && initflag ==0)
-	  { init_alloc();}
+#ifdef BABY_MALLOC_SIZE
+	if (GBC_enable == 0) return baby_malloc(size);
+#else	
+	if (GBC_enable==0) {
+	   if ( initflag ==0)
+	     init_alloc();
+	   else {
+#ifdef	     RECREATE_HEAP
+	     	RECREATE_HEAP
+#endif
+		;
+	   }
+	}
+
+#endif	
       
 
 	x = alloc_simple_string(size);
@@ -1048,6 +1107,10 @@ char *
  	object endp_temp;
 	if (ptr == 0)
 	  return;
+#ifdef BABY_MALLOC_SIZE
+	if ((void *)ptr < (void *) &baby_malloc_data[sizeof(baby_malloc_data)])
+	  return;
+#endif	
 	for (p = &malloc_list; *p && !endp(*p);  p = &((*p)->c.c_cdr))
 		if ((*p)->c.c_car->st.st_self == ptr) {
 			insert_contblock((*p)->c.c_car->st.st_self,
@@ -1072,6 +1135,22 @@ int size;
 	object x;
 	int i, j;
  	object endp_temp;
+	/* was allocated by baby_malloc */
+#ifdef BABY_MALLOC_SIZE	
+	if (ptr >= baby_malloc_data && ptr -baby_malloc_data <BABY_MALLOC_SIZE)
+	  {
+	    int dim = ((int *)ptr)[-1];
+	    if (dim > size)
+	      return ptr;
+	   else
+	  {  char *new= malloc(size);
+	     bcopy(ptr,new,dim);
+	     return new;
+	  }
+
+	  }
+#endif BABY_MALLOC_SIZE	
+
 	
 	if(ptr == NULL) return malloc(size);
 	for (x = malloc_list;  !endp(x);  x = x->c.c_cdr)
@@ -1095,10 +1174,6 @@ int size;
 
 #endif /* gnumalloc */
 
-DEFUN("STATICP",object,fSstaticp,SI,1,1,NONE,OO,OO,OO,OO,"Tell if the string or vector is static") (x)
-object x;
-{ RETURN1((inheap(x->ust.ust_self) ? sLt : sLnil));
-}
 
 char *
 calloc(nelem, elsize)
