@@ -96,8 +96,8 @@ DEF_ORDINARY("SIGNED-SHORT",sLsigned_short,LISP,"")
 DEF_ORDINARY("UNSIGNED-SHORT",sLunsigned_short,LISP,"")
 DEF_ORDINARY("*",sLA,LISP,"")
 DEF_ORDINARY("PLUSP",sLplusp,LISP,"")
-DEFCONST("CHAR-SIZE",sSchar_size,SI,(object)(small_fixnum_table+1024 +( 8  )) ,"Size in bits of a character")
-DEFCONST("SHORT-SIZE",sSshort_size,SI,(object)(small_fixnum_table+1024 +( 8 *sizeof(short) )) ,"Size in bits of a short integer")
+DEFCONST("CHAR-SIZE",sSchar_size,SI,(object)(small_fixnum_table+ 1024 +( 8  )) ,"Size in bits of a character")
+DEFCONST("SHORT-SIZE",sSshort_size,SI,(object)(small_fixnum_table+ 1024 +( 8 *sizeof(short) )) ,"Size in bits of a short integer")
 DEFUNO("FUNCALL",object,fLfuncall,LISP
    ,1,63 ,0 ,OO,OO,OO,OO,Lfuncall,"")
 DEFUNO("APPLY",object,fLapply,LISP
@@ -110,11 +110,11 @@ DEF_ORDINARY("LAMBDA-BLOCK-EXPANDED",sSlambda_block_expanded,SI,"")
 DEFVAR("*BREAK-POINTS*",sSAbreak_pointsA,SI,((object)&Cnil_body) ,"")
 DEFVAR("*BREAK-STEP*",sSAbreak_stepA,SI,((object)&Cnil_body) ,"")
 DEFUNO("MACROEXPAND",object,fLmacroexpand,LISP
-   ,1,2,0    ,OO,OO,OO,OO,Lmacroexpand,"")
+   ,1,2,0 ,OO,OO,OO,OO,Lmacroexpand,"")
 DEF_ORDINARY("FUNCALL",sLfuncall,LISP,"")
 DEFVAR("*MACROEXPAND-HOOK*",sLAmacroexpand_hookA,LISP,sLfuncall,"")
 DEF_ORDINARY("DEFMACRO*",sSdefmacroA,SI,"")
-DEFVAR("*INHIBIT-MACRO-SPECIAL*",sSAinhibit_macro_specialA,SI,		((object)&Cnil_body) ,"")
+DEFVAR("*INHIBIT-MACRO-SPECIAL*",sSAinhibit_macro_specialA,SI,((object)&Cnil_body) ,"")
 DEFUN("NULL",object,fLnot,LISP
    ,1,1,0 ,OO,OO,OO,OO,"")
 DEFUNO("NOT",object,fLnot,LISP
@@ -178,16 +178,16 @@ DEFUNO("SPICEP",object,fSspicep  ,SI
 DEFUNO("FIXNUMP",object,fSfixnump,SI
    ,1,1,0 ,OO,OO,OO,OO,siLfixnump,"")
 DEFUNO("SET",object,fLset,LISP
-   ,2,2,0    ,OO,OO,OO,OO,Lset,"")
+   ,2,2,0 ,OO,OO,OO,OO,Lset,"")
 DEFUNO("FSET",object,fSfset,SI
-   ,2,2,0    ,OO,OO,OO,OO,siLfset,"")
+   ,2,2,0 ,OO,OO,OO,OO,siLfset,"")
 DEFUNO("MAKUNBOUND",object,fLmakunbound,LISP
-   ,1,1,0    ,OO,OO,OO,OO,Lmakunbound,"")
+   ,1,1,0 ,OO,OO,OO,OO,Lmakunbound,"")
 DEFUNO("FMAKUNBOUND",object,fLfmakunbound,LISP
-   ,1,1,0    ,OO,OO,OO,OO,Lfmakunbound,"")
+   ,1,1,0 ,OO,OO,OO,OO,Lfmakunbound,"")
 DEF_ORDINARY("CLEAR-COMPILER-PROPERTIES",sSclear_compiler_properties,SI,"")
 DEFUNO("CLEAR-COMPILER-PROPERTIES",object,fSclear_compiler_properties,SI
-   ,2,2,0    ,OO,OO,OO,OO,siLclear_compiler_properties,"")
+   ,2,2,0 ,OO,OO,OO,OO,siLclear_compiler_properties,"")
 DEF_ORDINARY("AREF",sLaref,LISP,"")
 DEF_ORDINARY("CAR",sLcar,LISP,"")
 DEF_ORDINARY("CDR",sLcdr,LISP,"")
@@ -198,11 +198,9 @@ DEF_ORDINARY("FILL-POINTER",sLfill_pointer,LISP,"")
 DEF_ORDINARY("GET",sLget,LISP,"")
 DEF_ORDINARY("GETHASH",sLgethash,LISP,"")
 DEF_ORDINARY("INCF",sLincf,LISP,"")
-DEF_ORDINARY("LIST",sLlist,LISP,"")
 DEF_ORDINARY("POP",sLpop,LISP,"")
 DEF_ORDINARY("PUSH",sLpush,LISP,"")
 DEF_ORDINARY("SCHAR",sLschar,LISP,"")
-DEF_ORDINARY("SCHAR",sLschar,LISP,"")
 DEF_ORDINARY("SETF",sLsetf,LISP,"")
 DEF_ORDINARY("SETF-LAMBDA",sSsetf_lambda,SI,"")
 DEF_ORDINARY("STRUCTURE-ACCESS",sSstructure_access,SI,"")
@@ -248,6 +246,14 @@ DEF_ORDINARY("USE",sKuse,KEYWORD,"")
 DEFVAR("*PACKAGE*",sLApackageA,LISP,lisp_package,"")
 DEFUN("ALLOCATE-BIGGER-FIXNUM-RANGE",object,fSallocate_bigger_fixnum_range,
       SI,2,2,0 ,OI,IO,OO,OO,"")
+DEFUNO("CMOD",object,fScmod,SI
+   ,1,1,0 ,OO,OO,OO,OO,siLcmod,"")
+DEFUNO("CPLUS",object,fScplus,SI
+   ,2,2,0 ,OO,OO,OO,OO,siLcplus,"")
+DEFUNO("CTIMES",object,fSctimes,SI
+   ,2,2,0 ,OO,OO,OO,OO,siLctimes,"")
+DEFUNO("CDIFFERENCE",object,fScdifference,SI
+   ,2,2,0 ,OO,OO,OO,OO,siLcdifference,"")
 DEFUNO("NTH",object,fLnth,LISP,2,2,NONE,OI,OO,OO,OO,Lnth,"")
 DEFUN("FIRST",object,fLfirst,LISP,0,0,NONE,OO,OO,OO,OO,"")
 DEFUNO("SECOND",object,fLsecond,LISP,1,1,NONE,OO,OO,OO,OO,Lsecond,"")
@@ -315,14 +321,14 @@ DEFUNO("ARRAY-TOTAL-SIZE",int,fLarray_total_size,LISP,1,1,
        0 ,IO,OO,OO,OO,Larray_total_size,"")
 DEFUNO("ASET-BY-CURSOR",object,fSaset_by_cursor,SI,3,3,
        0 ,OO,OO,OO,OO,siLaset_by_cursor,"")
-DEFVAR("*MATCH-DATA*",sSAmatch_dataA,SI,		((object)&Cnil_body)  ,"")
-DEFVAR("*CASE-FOLD-SEARCH*",sSAcase_fold_searchA,SI,		((object)&Cnil_body)  ,
+DEFVAR("*MATCH-DATA*",sSAmatch_dataA,SI,((object)&Cnil_body)  ,"")
+DEFVAR("*CASE-FOLD-SEARCH*",sSAcase_fold_searchA,SI,((object)&Cnil_body)  ,
        "Non nil means that a string-match should ignore case")
-DEFUN("MATCH-BEGINNING",int,fSmatch_beginning,SI,1,1,0    ,II,OO,OO,OO,
+DEFUN("MATCH-BEGINNING",int,fSmatch_beginning,SI,1,1,0 ,II,OO,OO,OO,
    "Returns the beginning of the I'th match from the previous STRING-MATCH, where the 0th is for the whole regexp and the subsequent ones match parenthetical expressions.  -1 is returned if there is no match, or if the *match-data* vector is not a fixnum array.")
-DEFUN("MATCH-END",int,fSmatch_end,SI,1,1,0    ,II,OO,OO,OO,
+DEFUN("MATCH-END",int,fSmatch_end,SI,1,1,0 ,II,OO,OO,OO,
    "Returns the end of the I'th match from the previous STRING-MATCH")
-DEFUN("STRING-MATCH",int,fSstring_match,SI,2,4,0    ,IO,OI,IO,OO,
+DEFUN("STRING-MATCH",int,fSstring_match,SI,2,4,0 ,IO,OI,IO,OO,
       "Match regexp PATTERN in STRING starting in string starting at START and ending at END.  Return -1 if match not found, otherwise return the start index  of the first matchs.  The variable *MATCH-DATA* will be set to a fixnum array of sufficient size to hold the matches, to be obtained with match-beginning and match-end. If it already contains such an array, then the contents of it will be over written.   ")
 DEF_ORDINARY("S-DATA",sSs_data,SI,"")
 DEF_ORDINARY("COMPILE",sLcompile,LISP,"")
@@ -337,6 +343,12 @@ DEF_ORDINARY("VALUES",sLvalues,LISP,"")
 DEF_ORDINARY("VARIABLE-DOCUMENTATION",sSvariable_documentation,SI,"")
 DEF_ORDINARY("WARN",sLwarn,LISP,"")
 DEFVAR("*ALLOW-GZIPPED-FILE*",sSAallow_gzipped_fileA,SI,sLnil,"")
+DEF_ORDINARY("MYADDR",sKmyaddr,KEYWORD,"")
+DEF_ORDINARY("MYPORT",sKmyport,KEYWORD,"")
+DEF_ORDINARY("ASYNC",sKasync,KEYWORD,"")
+DEF_ORDINARY("HOST",sKhost,KEYWORD,"")
+DEF_ORDINARY("SERVER",sKserver,KEYWORD,"")
+DEF_ORDINARY("SOCKET",sSsocket,SI,"")
 DEFVAR("*STANDARD-INPUT*",sLAstandard_inputA,LISP,(init_file(),standard_io),"")
 DEFVAR("*STANDARD-OUTPUT*",sLAstandard_outputA,LISP,standard_io,"")
 DEFVAR("*ERROR-OUTPUT*",sLAerror_outputA,LISP,standard_io,"")
@@ -377,7 +389,6 @@ DEFVAR("*READ-SUPPRESS*",sLAread_suppressA,LISP,Cnil,"")
 DEF_ORDINARY("Y",sSY,SI,"")
 DEF_ORDINARY("YB",sSYB,SI,"")
 DEF_ORDINARY("YZ",sSYZ,SI,"")
-DEF_ORDINARY("LIST",sLlist,LISP,"")
 DEF_ORDINARY("LIST*",sLlistA,LISP,"")
 DEF_ORDINARY("APPEND",sLappend,LISP,"")
 DEF_ORDINARY("NCONC",sLnconc,LISP,"")
@@ -419,7 +430,7 @@ DEFUNO("FORMAT",object,fLformat,LISP
    ,2,((1<< 6 ) -1) ,0 ,OO,OO,OO,OO,Lformat,"")
 DEFVAR("*INDENT-FORMATTED-OUTPUT*",sSAindent_formatted_outputA,SI,((object)&Cnil_body) ,"")
 DEFUNO("DELETE-FILE",object,fLdelete_file,LISP
-   ,1,1,0    ,OO,OO,OO,OO,Ldelete_file,"")
+   ,1,1,0 ,OO,OO,OO,OO,Ldelete_file,"")
 DEFUNO("ERROR",object,fLerror,LISP
    ,1,((1<< 6 ) -1) ,0 ,OO,OO,OO,OO,Lerror,"")
 DEFUNO("CERROR",object,fLcerror,LISP
@@ -475,18 +486,16 @@ DEF_ORDINARY("CATCH",sKcatch,KEYWORD,"")
 DEF_ORDINARY("PROTECT",sKprotect,KEYWORD,"")
 DEF_ORDINARY("CATCHALL",sKcatchall,KEYWORD,"")
 DEFUNO("GET-UNIVERSAL-TIME",object,fLget_universal_time,LISP
-   ,0,0,0,OO,OO,OO,OO,Lget_universal_time,"")
-DEFVAR("*DEFAULT-TIME-ZONE*",sSAdefault_time_zoneA,SI,make_fixnum((-9)),"")
-DEFUN("GETPID",int,fSgetpid,SI,0,0,0    ,IO,OO,OO,OO,
+   ,0,0,0 ,OO,OO,OO,OO,Lget_universal_time,"")
+DEFUN("GET-INTERNAL-REAL-TIME",int,fLget_internal_real_time,LISP,0,0,0 ,IO,OO,OO,OO,"Run time relative to beginning")
+DEFVAR("*DEFAULT-TIME-ZONE*",sSAdefault_time_zoneA,SI,make_fixnum((-9) ),"")
+DEFUN("GETPID",int,fSgetpid,SI,0,0,0 ,IO,OO,OO,OO,
       "getpid  returns  the  process  ID  of the current process")
 DEFUN("USE-FAST-LINKS",object,fSuse_fast_links,SI,1,2,0 ,OO,OO,OO,OO,
 
       "Usage: (use-fast-links {nil,t} &optional fun) turns on or off the fast linking depending on FLAG, so that things will either go faster, or turns it off so that stack information is kept.  If SYMBOL is supplied and FLAG is nil, then this function is deleted from the fast links")
 DEF_ORDINARY("CDEFN",sScdefn,SI,"")
 DEFVAR("*LINK-ARRAY*",sLAlink_arrayA,LISP,((object)&Cnil_body) ,"")
-DEFUNO("PROFILE",object,fSprofile,SI
-   ,2,2,0 ,OO,OO,OO,OO,siLprofile,
-       "Sets up profiling with START-ADDRESS and  SCALE where scale is   between 0 and 256")
 DEFUNO("FUNCTION-START",object,fSfunction_start,SI
    ,1,1,0 ,OO,OO,OO,OO,siLfunction_start,"")
 DEFUNO("READ-EXTERNALS",object,fSread_externals,SI
@@ -498,7 +507,7 @@ DEFUNO("DISPLAY-PROFILE",object,fSdisplay_profile,SI
 DEFUNO("ARRAY-ADRESS",object,fSarray_adress,SI
    ,1,1,0 ,OO,OO,OO,OO,siLarray_adress,"")
 DEFVAR("*PROFILE-ARRAY*",sSAprofile_arrayA,SI,((object)&Cnil_body) ,"")
-DEFVAR("*INTERRUPT-ENABLE*",sSAinterrupt_enableA,SI,		((object)&Ct_body)  ,"")
+DEFVAR("*INTERRUPT-ENABLE*",sSAinterrupt_enableA,SI,((object)&Ct_body)  ,"")
 DEF_ORDINARY("SIGUSR1-INTERRUPT",sSsigusr1_interrupt,SI,"")
 DEF_ORDINARY("SIGIO-INTERRUPT",sSsigio_interrupt,SI,"")
 DO_INIT(init_safety();)
@@ -551,4 +560,10 @@ DEFUN("CHECK-STATE-INPUT",int ,fScheck_state_input,SI,2,2,0 ,IO,IO,OO,OO,
       "")
 DEFUN("CLEAR-CONNECTION-STATE",int,fSclear_connection_state,
       SI,1,1,0 ,IO,OO,OO,OO,
-      "Read on FD until nothing left to read.  Return number of bytes read")}
+      "Read on FD until nothing left to read.  Return number of bytes read")
+DEFUN("GETPEERNAME",object,fSgetpeername,SI,1,1,0 ,OO,OO,OO,OO,
+ "Return a list of three elements: the address, the hostname and the port for the other end of the socket.  If hostname is not available it will be equal to the address.  Invalid on server sockets. Return NIL on failure.")
+DEFUN("GETSOCKNAME",object,fSgetsockname,SI,1,1,0 ,OO,OO,OO,OO,
+ "Return a list of three elements: the address, the hostname and the port for the socket.  If hostname is not available it will be equal to the address. Return NIL on failure. ")
+DEFUN("SET-BLOCKING",int,fSset_blocking,SI,2,2,0 ,IO,OO,OO,OO,
+      "Set blocking on if MODE is T otherwise off.  Return 0 if succeeds. Otherwise the error number.")}
