@@ -37,6 +37,8 @@ which is usually 60 maybe 100 or something else. */
 #define HZ 60
 #endif
 
+#define HZ1 (HZ > 100 ? 100 : HZ)
+
 #ifdef USE_ATT_TIME
 #undef BSD
 #define ATT
@@ -54,22 +56,18 @@ static struct timeb beginning;
 long beginning;
 #endif
 
-#ifdef E15
-#include <sys/times.h>
-long beginning;
-#endif
-
-#ifdef DGUX
-
-
-#endif
-
 runtime()
 {
-	struct tms buf;
 
-	times(&buf);
-	return(buf.tms_utime);
+#ifdef USE_INTERNAL_REAL_TIME_FOR_RUNTIME
+    return fLget_internal_real_time();
+#else	
+	{
+	  struct tms buf;
+	  times(&buf);
+	  return(buf.tms_utime);
+	}
+#endif
 }
 
 object
@@ -117,21 +115,29 @@ Lsleep()
 
 Lget_internal_run_time()
 {
+
+#ifdef USE_INTERNAL_REAL_TIME_FOR_RUNTIME
+        vs_push(make_fixnum(fLget_internal_real_time()));
+	return;
+#else
 	struct tms buf;
 
 	check_arg(0);
 	times(&buf);
 	vs_push(make_fixnum(buf.tms_utime));
 	vs_push(make_fixnum(buf.tms_cutime));
+
+#endif	
 	
 }
 
-Lget_internal_real_time()
+
+DEFUN("GET-INTERNAL-REAL-TIME",int,fLget_internal_real_time,LISP,0,0,NONE,IO,OO,OO,OO,"Run time relative to beginning")
+     ()
 {
 #ifdef BSD
 	static struct timeval begin_tzp;
 	struct timeval tzp;
-	check_arg(0);
 	if (begin_tzp.tv_sec==0)
 	  gettimeofday(&begin_tzp,0);
 	gettimeofday(&tzp,0);
@@ -139,24 +145,11 @@ Lget_internal_real_time()
    plus the fraction of a second.  We must make it relative, so this
    will only wrap if the process lasts longer than 818 days
    */
-	vs_push(make_fixnum((tzp.tv_sec-begin_tzp.tv_sec)*HZ
-			    + ((tzp.tv_usec)*HZ)/1000000));
-
+	return ((tzp.tv_sec-begin_tzp.tv_sec)*HZ1
+			    + ((tzp.tv_usec)*HZ1)/1000000);
 #endif
-
 #ifdef ATT
-	check_arg(0);
-	vs_push(make_fixnum((time(0) - beginning)*HZ));
-#endif
-
-#ifdef E15
-	check_arg(0);
-	vs_push(make_fixnum((time(0) - beginning)*HZ));
-#endif
-
-#ifdef DGUX
-
-
+	return ((time(0) - beginning)*HZ1);
 #endif
 }
 
@@ -170,18 +163,9 @@ init_unixtime()
 #ifdef ATT
 	beginning = time(0);
 #endif
-#ifdef E15
-	beginning = time(0);
-#endif
-#ifdef DGUX
 
-#endif
-
-
-
-	make_constant("INTERNAL-TIME-UNITS-PER-SECOND", make_fixnum(HZ));
+	make_constant("INTERNAL-TIME-UNITS-PER-SECOND", make_fixnum(HZ1));
 
 	make_function("SLEEP", Lsleep);
 	make_function("GET-INTERNAL-RUN-TIME", Lget_internal_run_time);
-	make_function("GET-INTERNAL-REAL-TIME", Lget_internal_real_time);
 }
